.. _spkg_database_jones_numfield:

database_jones_numfield: Table of number fields
===============================================

Description
-----------

This is a table of number fields with bounded ramification and degree
at most 6.

License
-------

GPLv2+


Upstream Contact
----------------

sage-devel@googlegroups.com


Type
----

optional


Dependencies
------------



Version Information
-------------------

package-version.txt::

    4

See https://repology.org/project/sage-data-jones-numfield/versions

Installation commands
---------------------

.. tab:: Sage distribution:

   .. CODE-BLOCK:: bash

       $ sage -i database_jones_numfield


However, these system packages will not be used for building Sage
because ``spkg-configure.m4`` has not been written for this package;
see :issue:`27330` for more information.
